@@ -102,7 +102,7 @@ johndoe[1:4]$"V20Gy,Dmax"
 ###################################################
 ### code chunk number 15: RadOnc.Rnw:152-153
 ###################################################
-johndoe[["DUODENUM"]][c("V5", "VGy", "volume", 2.5, "", "Dmax")]
+johndoe[["DUODENUM"]][c("V5", "VGy", "volume", 2.5, "", "Dmax%")]
 
 
 ###################################################
